@@ -37,5 +37,5 @@ def decrypt_file(file_name, key):
     with open(file_name, "rb") as fo:
         ciphertext = fo.read()
     dec = decrypt(ciphertext, key)
-    with open(file_name[:-4]+".test", "wb") as fo:
+    with open(file_name[:-4], "wb") as fo:
         fo.write(dec)
