@@ -69,7 +69,7 @@ class AppRankScrapy:
             r = requests.get(url=self.appinfo_url, params=params, headers=self.headers)
             time.sleep(SLEEP_TIME)
             # appname
-            app_name = json.loads(r.text)["appInfo"]["appname"]
+            app_name = json.loads(r.text.encode("utf-8"))["appInfo"]["appname"]
             appinfo_df = pd.DataFrame(
                 dict(app_id=[app_id], app_name=[app_name], create_time=[datetime.now().strftime("%Y-%m-%d %H:%M:%S")])
             )
